searchData={"items":[{"type":"behaviour","title":"PgRanges","doc":"PgRanges provides a simple wrapper around `Postgrex.Range` so that you can\ncreate schemas with range type fields and use the native range type in\nmigrations.\n\n    defmodule MyApp.Employee do\n      use Ecto.Schema\n      alias PgRanges.DateRange\n\n      schema \"employees\" do\n        field :name, :string\n        field :employed_dates, DateRange\n      end\n    end\n\n    defmodule MyApp.Repo.Migrations.CreateEmployees do\n      use Ecto.Migration\n\n      def change do\n        create table(:employees) do\n          add :name, :string\n          add :employed_dates, :daterange\n        end\n      end\n    end\n\nWhen used in composing queries, you must cast to the PgRange type.\n\n    import Ecto.Query\n    alias PgRanges.DateRange\n    alias MyApp.Repo\n\n    range = DateRange.new(~D[2018-11-01], ~D[2019-01-01])\n\n    Repo.all(\n      from e in Employee,\n      where: fragment(\"? @> ?\", e.employed_dates, type(^range, DateRange))\n    )","ref":"PgRanges.html"},{"type":"callback","title":"PgRanges.from_postgrex/1","doc":"","ref":"PgRanges.html#c:from_postgrex/1"},{"type":"callback","title":"PgRanges.new/2","doc":"","ref":"PgRanges.html#c:new/2"},{"type":"callback","title":"PgRanges.new/3","doc":"","ref":"PgRanges.html#c:new/3"},{"type":"callback","title":"PgRanges.to_postgrex/1","doc":"","ref":"PgRanges.html#c:to_postgrex/1"},{"type":"module","title":"PgRanges.DateRange","doc":"Wraps a `Postgrex.Range` and casts to a PostgreSQL `daterange` type.","ref":"PgRanges.DateRange.html"},{"type":"function","title":"PgRanges.DateRange.embed_as/1","doc":"","ref":"PgRanges.DateRange.html#embed_as/1"},{"type":"function","title":"PgRanges.DateRange.equal?/2","doc":"","ref":"PgRanges.DateRange.html#equal?/2"},{"type":"function","title":"PgRanges.DateRange.new/3","doc":"","ref":"PgRanges.DateRange.html#new/3"},{"type":"type","title":"PgRanges.DateRange.t/0","doc":"","ref":"PgRanges.DateRange.html#t:t/0"},{"type":"module","title":"PgRanges.Int4Range","doc":"Wraps a `Postgrex.Range` and casts to a PostgreSQL `int4range` type.","ref":"PgRanges.Int4Range.html"},{"type":"function","title":"PgRanges.Int4Range.embed_as/1","doc":"","ref":"PgRanges.Int4Range.html#embed_as/1"},{"type":"function","title":"PgRanges.Int4Range.equal?/2","doc":"","ref":"PgRanges.Int4Range.html#equal?/2"},{"type":"function","title":"PgRanges.Int4Range.new/3","doc":"","ref":"PgRanges.Int4Range.html#new/3"},{"type":"type","title":"PgRanges.Int4Range.t/0","doc":"","ref":"PgRanges.Int4Range.html#t:t/0"},{"type":"module","title":"PgRanges.Int8Range","doc":"Wraps a `Postgrex.Range` and casts to a PostgreSQL `int8range` type.","ref":"PgRanges.Int8Range.html"},{"type":"function","title":"PgRanges.Int8Range.embed_as/1","doc":"","ref":"PgRanges.Int8Range.html#embed_as/1"},{"type":"function","title":"PgRanges.Int8Range.equal?/2","doc":"","ref":"PgRanges.Int8Range.html#equal?/2"},{"type":"function","title":"PgRanges.Int8Range.new/3","doc":"","ref":"PgRanges.Int8Range.html#new/3"},{"type":"type","title":"PgRanges.Int8Range.t/0","doc":"","ref":"PgRanges.Int8Range.html#t:t/0"},{"type":"module","title":"PgRanges.NumRange","doc":"Wraps a `Postgrex.Range` and casts to a PostgreSQL `numrange` type.","ref":"PgRanges.NumRange.html"},{"type":"function","title":"PgRanges.NumRange.embed_as/1","doc":"","ref":"PgRanges.NumRange.html#embed_as/1"},{"type":"function","title":"PgRanges.NumRange.equal?/2","doc":"","ref":"PgRanges.NumRange.html#equal?/2"},{"type":"function","title":"PgRanges.NumRange.new/3","doc":"Creates a new `Elixir.PgRanges.NumRange` struct. It expects the _lower_ and _upper_\nattributes to be acceptable by `Decimal.new/1`.\n\nThis will convert any acceptable input to Decimal.","ref":"PgRanges.NumRange.html#new/3"},{"type":"function","title":"Options - PgRanges.NumRange.new/3","doc":"- `lower_inclusive`: should the range be lower inclusive? Default is `true`\n- `upper_inclusive`: should the range be upper inclusive? Default is `false`","ref":"PgRanges.NumRange.html#new/3-options"},{"type":"type","title":"PgRanges.NumRange.t/0","doc":"","ref":"PgRanges.NumRange.html#t:t/0"},{"type":"module","title":"PgRanges.TsRange","doc":"Wraps a `Postgrex.Range` and casts to a PostgreSQL `tsrange` type.","ref":"PgRanges.TsRange.html"},{"type":"function","title":"PgRanges.TsRange.embed_as/1","doc":"","ref":"PgRanges.TsRange.html#embed_as/1"},{"type":"function","title":"PgRanges.TsRange.equal?/2","doc":"","ref":"PgRanges.TsRange.html#equal?/2"},{"type":"function","title":"PgRanges.TsRange.new/3","doc":"","ref":"PgRanges.TsRange.html#new/3"},{"type":"type","title":"PgRanges.TsRange.t/0","doc":"","ref":"PgRanges.TsRange.html#t:t/0"},{"type":"module","title":"PgRanges.TstzRange","doc":"Wraps a `Postgrex.Range` and casts to a PostgreSQL `tstzrange` type.","ref":"PgRanges.TstzRange.html"},{"type":"function","title":"PgRanges.TstzRange.embed_as/1","doc":"","ref":"PgRanges.TstzRange.html#embed_as/1"},{"type":"function","title":"PgRanges.TstzRange.equal?/2","doc":"","ref":"PgRanges.TstzRange.html#equal?/2"},{"type":"function","title":"PgRanges.TstzRange.new/3","doc":"Creates a new `Elixir.PgRanges.TstzRange` struct. It expects the _lower_ and _upper_\nattributes to be `DateTime`s.\n\nThis will convert the date time structs to UTC time.","ref":"PgRanges.TstzRange.html#new/3"},{"type":"function","title":"Options - PgRanges.TstzRange.new/3","doc":"- `lower_inclusive`: should the range be lower inclusive? Default is `true`\n- `upper_inclusive`: should the range be upper inclusive? Default is `false`","ref":"PgRanges.TstzRange.html#new/3-options"},{"type":"type","title":"PgRanges.TstzRange.t/0","doc":"","ref":"PgRanges.TstzRange.html#t:t/0"}],"content_type":"text/markdown"}